@@ -10,11 +10,11 @@ Regexp::Pattern::License::Parts - Regular expressions for licensing sub-parts
 
 =head1 VERSION
 
-Version v3.7.1
+Version v3.8.0
 
 =cut
 
-our $VERSION = version->declare("v3.7.1");
+our $VERSION = version->declare("v3.8.0");
 
 =head STATUS
 
@@ -86,8 +86,12 @@ our %RE = (
 		pat =>
 			'to deal in the Software without restriction, including without limitation the rights '
 	},
-	to_copy_prg      => { pat => 'to use or copy this program ' },
-	to_dist          => { pat => 'to use, copy, modify,? and distribute ' },
+	to_copy_prg  => { pat => 'to use or copy this program ' },
+	to_dist      => { pat => 'to use, copy, modify,? and distribute ' },
+	to_reproduce => {
+		pat =>
+			'to use, reproduce, prepare derivative works, and to redistribute to others'
+	},
 	to_mod_sublic_sw => {
 		pat =>
 			'to use, copy, modify, merge, publish, distribute, sublicense, and[/]or sell copies of the Software, '
